var Details = function()
{
	var details = {};
	var debug = 0;
	
	// Page initialization
	details.initPage = function()
	{
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnSave', details.saveDetails);

		Events.addEventHandler('dnaVolume', 'keypress', Events.numberOnly);
		Events.addEventHandler('rnaVolume', 'keypress', Events.numberOnly);
		
		var index = Data.int('page-data', 'index');
		var frm = document.forms['details'];
		var pfrm = window.opener.document.forms['meludi'];

		//var specimen = pfrm.extractSourceItems[index].specimen;
		var selItemsList = getSelectedItemsList();
		var item = selItemsList[index];
		var specimen = item;

		frm.qiacubePosition.value = specimen.qiacubePosition;
		frm.dnaVolume.value = specimen.dna.volume;
		frm.rnaVolume.value = specimen.rna.volume;

		frm.specimenComment.value = specimen.comment || '';
		frm.dnaComment.value = specimen.dna.comment || '';
		frm.rnaComment.value = specimen.rna.comment || '';

		var reagents = window.opener.ExtractionReg.REAGENTS;
		for (var i = 0; i < reagents.length; i++)
		{
			var rg = reagents[i];
			frm[rg].value = specimen[rg] || '';
			Doc.element(rg+'.default').innerHTML = Strings.encodeTags(pfrm[rg].value);
		}
		
		details.checkForm();
		frm.qiacubePosition.focus();
	}
	
	details.checkForm = function()
	{
		var frm = document.forms['details'];
		
		var index = Data.int('page-data', 'index');
		var selItemsList = getSelectedItemsList();
		var item = selItemsList[index];

		// Qiacube position
		var qiacubePositionStr = frm.qiacubePosition.value;
		if (isSpecimen(item))
		{
			// Check prefix indicating QIAcube instrument
			var qiacubeInstrPrefix = qiacubePositionStr.substring(0,1);
			if (/^[A-Z]$/.test(qiacubeInstrPrefix) == false)
			{
				Forms.showNotification('qiacubePosition', 'QIAcube instrument prefix must be uppercase letter A-Z.');
				return false;
			}
			// Remove prefix indicating QIAcube instrument
			qiacubePositionStr = qiacubePositionStr.substring(1);
			var qiacubePosition = parseInt(qiacubePositionStr, 10);
			if (qiacubePosition < 1 || qiacubePosition > 12)
			{
				Forms.showNotification('qiacubePosition', 'QIAcube position must be between 1 and 12.');
				return false;
			}
		}
		else
		{
			if (qiacubePositionStr)
			{
				Forms.showNotification('qiacubePosition', 'Input RNA and DNA do not have a QIAcube position.');
				return false;
			}
		}

		// DNA
		var dnaVolume = parseFloat(frm.dnaVolume.value);
		if (!(dnaVolume > 0))
		{
			Forms.showNotification('dnaVolume', 'Invalid value for DNA volume.');
			return false;
		}

		// RNA
		var rnaVolume = parseFloat(frm.rnaVolume.value);
		if (!(rnaVolume > 0))
		{
			Forms.showNotification('rnaVolume', 'Invalid value for RNA volume.');
			showError('Invalid value for RNA volume.');
			return false;
		}

		return true;
	}

	details.saveDetails = function()
	{
		if (!details.checkForm()) return;
		
		var index = Data.int('page-data', 'index');
		var mode = Data.get('page-data', 'mode');
		//var specimen = window.opener.document.forms['meludi'].extractSourceItems[index].specimen;
		//var specimen = pfrm.extractSourceItems[index].specimen;
		var selItemsList = getSelectedItemsList();
		var item = selItemsList[index];
		var specimen = item;
		var frm = document.forms['details'];

		specimen.qiacubePosition = frm.qiacubePosition.value;
		specimen.comment = frm.specimenComment.value;

		specimen.dna.volume = parseFloat(frm.dnaVolume.value);
		specimen.dna.comment = frm.dnaComment.value;
		specimen.rna.volume = parseFloat(frm.rnaVolume.value);
		specimen.rna.comment = frm.rnaComment.value;

		if (mode != null && mode == 'ExtractionReg')
		{
			var reagents = window.opener.ExtractionReg.REAGENTS;
			for (var i = 0; i < reagents.length; i++)
			{
				var rg = reagents[i];
				specimen[rg] = frm[rg].value || null;
			}
		}

		if (mode != null && mode == 'ExtractionReg')
		{
			window.opener.ExtractionReg.updateDetailsTable();
		}
		else
		{
			window.opener.ExtractionPrep.updateDetailsTable();
		}
		window.close();
	}

	isSpecimen = function(item)
	{
		var isSpecimen = false;
		if (item != null)
		{
			if (!isRna(item) && !isDna(item))
			{
				isSpecimen = true;
			}
		}
		return isSpecimen;
	}

	isRna = function(item)
	{
		var isRna = false;
		if (item != null)
		{
			var name = item.name;
			if (name != null)
			{
				// Check if item name ends with ".r"
				if (name.indexOf('.r') == (name.length - 2))
				{
					isRna = true;
				}
			}
		}
		return isRna;
	}

	isDna = function(item)
	{
		var isDna = false;
		if (item != null)
		{
			var name = item.name;
			if (name != null)
			{
				// Check if item name ends with ".d"
				if (name.indexOf('.d') == (name.length - 2))
				{
					isDna = true;
				}
			}
		}
		return isDna;
	}

	getSelectedItemsList = function()
	{
		var pfrm = window.opener.document.forms['meludi'];
		
		// Get number of selected extract source items
		var numItems = 0;
		var selItemsList = [];
		for (var i = 0; i < pfrm.extractSourceItems.length; i++)
		{
			if (pfrm.extractSourceItems[i].selected)
			{
				if (pfrm.extractSourceItems[i].item != null)
				{
					selItemsList[numItems] = pfrm.extractSourceItems[i].item;
					numItems++;
				}
			}
		}
		return selItemsList;
	}
	
	return details;
}();

Doc.onLoad(Details.initPage);

